package com.xkrs.dao;

import com.xkrs.model.entity.CountyEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @author XinYi Song
 */
@Component
public interface CountyDao extends JpaRepository<CountyEntity, Long> {
    /**
     * 查询市包含的区县和编码
     *
     * @param code
     * @return
     */
    @Query(value = "select county_name cityname,county_code citycode from county where city_code = :code", nativeQuery = true)
    List<Map<String, Object>> selectCountyName(String code);

    /**
     * 根据市编码查询信息
     *
     * @param cityCode
     * @return
     */
    List<CountyEntity> findByCityCode(String cityCode);

    List<CountyEntity> findByCityName(String cityName);

    /**
     * 根据countyCode查询信息
     *
     * @param countyCode
     * @return
     */
    List<CountyEntity> findByCountyCode(String countyCode);

    /**
     * 根据县名称查询信息
     *
     * @param countyName
     * @return
     */
    List<CountyEntity> findByCountyName(String countyName);

}
